@@ -95,5 +95,7 @@ L<Bio::Perl>, L<Bio::DB::HTS>, L<Bio::DB::HTS::Alignment>, L<Bio::DB::HTS::Const
 # documentation only
 
 package Bio::DB::HTS::Pileup;
-$Bio::DB::HTS::Pileup::VERSION = '1.06';
+use strict;
+use warnings;
+$Bio::DB::HTS::Pileup::VERSION = '1.07';
 1;
